@@ -30,14 +30,14 @@ class ExportCommand(Command):
                             help="BibLaTeX output file")
         parser.add_argument("-z", "--zip", type=argparse.FileType('a'),
                             help="zip output file")
-        parser.add_argument('list_args', nargs=argparse.REMAINDER)
+        parser.add_argument('list_args', nargs='*')
 
         if not args:
             parser.print_usage(sys.stderr)
             sys.exit(1)
 
         try:
-            largs = parser.parse_args(args)
+            largs = parser.parse_intermixed_args(args)
         except argparse.ArgumentError as exc:
             print("{}: {}".format(exc.argument_name, exc.message), file=sys.stderr)
             return
