@@ -4,6 +4,38 @@ from copy import deepcopy
 import configparser
 import io
 import os
+import sys
+
+DEFAULTS = {
+    'DATABASE': {
+        'file': os.path.expanduser('~/.local/share/cobib/literature.yaml'),
+        'open': 'xdg-open' if sys.platform.lower() == 'linux' else 'open',
+        'grep': 'grep',
+    },
+    'FORMAT': {
+        'month': 'int',
+        'ignore_non_standard_types': False,
+    },
+    'TUI': {
+        'default_list_args': '-l',
+        'prompt_before_quit': True,
+        'reverse_order': True,
+    },
+    'KEY_BINDINGS': {
+    },
+    'COLORS': {
+        'cursor_line_fg': 'white',
+        'cursor_line_bg': 'cyan',
+        'top_statusbar_fg': 'black',
+        'top_statusbar_bg': 'yellow',
+        'bottom_statusbar_fg': 'black',
+        'bottom_statusbar_bg': 'yellow',
+        'search_label_fg': 'blue',
+        'search_label_bg': 'black',
+        'search_query_fg': 'red',
+        'search_query_bg': 'black',
+    },
+}
 
 
 class Config:
@@ -25,6 +57,8 @@ class Config:
         """
         ini_conf = configparser.ConfigParser()
         ini_conf.optionxform = str  # makes option names case-sensitive!
+        # load default configuration
+        ini_conf.read_dict(DEFAULTS)
 
         # read ini config file
         if configpath is not None:
@@ -33,11 +67,8 @@ class Config:
             ini_conf.read(configpath)
         elif os.path.exists(os.path.expanduser('~/.config/cobib/config.ini')):
             ini_conf.read(os.path.expanduser('~/.config/cobib/config.ini'))
-        else:
-            root = os.path.abspath(os.path.dirname(__file__))
-            ini_conf.read(os.path.join(root, 'docs', 'default.ini'))
 
-        # copy sections into dictionary
+        # overwrite settings
         for section in ini_conf.sections():
             self.config[section] = deepcopy(ini_conf[section])
 
